@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Executor;
-$Test::BDD::Cucumber::Executor::VERSION = '0.650001'; # TRIAL
+$Test::BDD::Cucumber::Executor::VERSION = '0.660002'; # TRIAL
 =head1 NAME
 
 Test::BDD::Cucumber::Executor - Run through Feature and Harness objects
 
 =head1 VERSION
 
-version 0.650001
+version 0.660002
 
 =head1 DESCRIPTION
 
@@ -26,16 +26,18 @@ use Number::Range;
 use Carp qw/croak/;
 our @CARP_NOT;
 
-use Test2::API qw/intercept context/;
+use Test2::API qw/intercept/;
 
 # Use-ing the formatter results in a
 # 'loaded too late to be used globally' warning
 # But we only need it locally anyway.
 require Test2::Formatter::TAP;
 
+use Test2::Bundle::More ();
 # Needed for subtest() -- we don't want to import all its functions though
 require Test::More;
 
+use Test::BDD::Cucumber::StepFile ();
 use Test::BDD::Cucumber::StepContext;
 use Test::BDD::Cucumber::Util;
 use Test::BDD::Cucumber::Model::Result;
@@ -600,18 +602,9 @@ sub dispatch {
         ###TODO: Both intercept() and Test::More::subtest() should
         # be replaced by a specific Hub implementation for T::B::C
         Test::More::subtest( 'execute step', sub {
-            my $ctx = context();
-            $ctx->pass( "Starting to execute step: " . $context->text );
-
-            # Execute!
-            no warnings 'redefine';
-
-            local *Test::BDD::Cucumber::StepFile::S = sub {
-                return $context->stash->{'scenario'};
-            };
-            local *Test::BDD::Cucumber::StepFile::C = sub {
-                return $context;
-            };
+            Test2::Bundle::More::pass(
+                "Starting to execute step: " . $context->text
+                );
 
             # Take a copy of this. Turns out actually matching against it
             # directly causes all sorts of weird-ass heisenbugs which mst has
@@ -627,13 +620,23 @@ sub dispatch {
             @match_locations = pairwise { [ $a, $b ] } @starts, @ends;
 
             # OK, actually execute
-            eval { $coderef->($context) };
+            eval {
+                no warnings 'redefine';
+
+                local *Test::BDD::Cucumber::StepFile::_S = sub {
+                    return $context->stash->{'scenario'};
+                };
+                local *Test::BDD::Cucumber::StepFile::_C = sub {
+                    return $context;
+                };
+
+                $coderef->($context)
+            };
             if ($@) {
-                $ctx->fail("Step ran successfully", $@);
+                Test2::Bundle::More::fail("Step ran successfully", $@);
             }
 
-            $ctx->done_testing;
-            $ctx->release;
+            Test2::Bundle::More::done_testing();
                              });
     };
 
